TileBuilderData<T extends Object> class final

Constructors

TileBuilderData({required T model, required int selectionIndex, required VoidCallback onSelect})
const

Properties

asTuple → (T, bool, VoidCallback)
no setter
hashCode int
The hash code for this object.
no setterinherited
isSelected bool
no setter
model → T
final
onSelect VoidCallback
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionIndex int
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited